@@ -1,9 +1,7 @@
-from . import DeploymentsClient, ExperimentsClient, HyperparameterJobsClient, ModelsClient, ProjectsClient, \
+from . import ModelsClient, ProjectsClient, \
     MachinesClient, NotebooksClient, SecretsClient, DatasetsClient, MachineTypesClient, DatasetVersionsClient, \
     DatasetTagsClient, ClustersClient, StorageProvidersClient
-from .job_client import JobsClient
 from .workflow_client import WorkflowsClient
-from .tensorboards_client import TensorboardClient
 from .. import logger as sdk_logger
 
 
@@ -18,11 +16,6 @@ class SdkClient(object):
         self.dataset_tags = DatasetTagsClient(api_key=api_key, logger=logger)
         self.dataset_versions = DatasetVersionsClient(
             api_key=api_key, logger=logger)
-        self.deployments = DeploymentsClient(api_key=api_key, logger=logger)
-        self.experiments = ExperimentsClient(api_key=api_key, logger=logger)
-        self.hyperparameters = HyperparameterJobsClient(
-            api_key=api_key, logger=logger)
-        self.jobs = JobsClient(api_key=api_key, logger=logger)
         self.machine_types = MachineTypesClient(api_key=api_key, logger=logger)
         self.machines = MachinesClient(api_key=api_key, logger=logger)
         self.models = ModelsClient(api_key=api_key, logger=logger)
@@ -31,5 +24,4 @@ class SdkClient(object):
         self.secrets = SecretsClient(api_key=api_key, logger=logger)
         self.storage_providers = StorageProvidersClient(
             api_key=api_key, logger=logger)
-        self.tensorboards = TensorboardClient(api_key=api_key, logger=logger)
         self.workflows = WorkflowsClient(api_key=api_key, logger=logger)
